@@ -17,7 +17,9 @@ from six.moves.urllib import parse
 from barbican import api
 from barbican.api import controllers
 from barbican.api.controllers import acls
+from barbican.api.controllers import consumers
 from barbican.api.controllers import secretmeta
+from barbican.common import accept
 from barbican.common import exception
 from barbican.common import hrefs
 from barbican.common import quota
@@ -36,8 +38,7 @@ LOG = utils.getLogger(__name__)
 
 def _secret_not_found():
     """Throw exception indicating secret not found."""
-    pecan.abort(404, u._('Not Found. Sorry but your secret is in '
-                         'another castle.'))
+    pecan.abort(404, u._('Secret not found.'))
 
 
 def _invalid_secret_id():
@@ -76,6 +77,8 @@ class SecretController(controllers.ACLMixin):
     def __init__(self, secret):
         LOG.debug('=== Creating SecretController ===')
         self.secret = secret
+        self.consumers = consumers.SecretConsumersController(secret.id)
+        self.consumer_repo = repo.get_secret_consumer_repository()
         self.transport_key_repo = repo.get_transport_key_repository()
 
     def get_acl_tuple(self, req, **kwargs):
@@ -104,7 +107,7 @@ class SecretController(controllers.ACLMixin):
                     pecan.abort(405)
         else:
             # only 'acl' and 'metadata' as sub-resource is supported
-            pecan.abort(405)
+            pecan.abort(404)
 
     @pecan.expose(generic=True)
     def index(self, **kwargs):
@@ -159,8 +162,11 @@ class SecretController(controllers.ACLMixin):
         project = res.get_or_create_project(external_project_id)
 
         # default to application/octet-stream if there is no Accept header
-        accept_header = getattr(pecan.request.accept, 'header_value',
-                                'application/octet-stream')
+        if (type(pecan.request.accept) is accept.NoHeaderType or
+                not pecan.request.accept.header_value):
+            accept_header = 'application/octet-stream'
+        else:
+            accept_header = pecan.request.accept.header_value
         pecan.override_template('', accept_header)
 
         # check if payload exists before proceeding
@@ -250,9 +256,26 @@ class SecretController(controllers.ACLMixin):
     @controllers.handle_exceptions(u._('Secret deletion'))
     @controllers.enforce_rbac('secret:delete')
     def on_delete(self, external_project_id, **kwargs):
+        secret_consumers = self.consumer_repo.get_by_secret_id(
+            self.secret.id,
+            suppress_exception=True
+        )
+
+        # With ACL support, the user token project does not have to be same as
+        # project associated with secret. The lookup project_id needs to be
+        # derived from the secret's data considering authorization is already
+        # done.
+        external_project_id = self.secret.project.external_id
         plugin.delete_secret(self.secret, external_project_id)
         LOG.info('Deleted secret for project: %s', external_project_id)
 
+        for consumer in secret_consumers[0]:
+            try:
+                self.consumer_repo.delete_entity_by_id(
+                    consumer.id, external_project_id)
+            except exception.NotFound:  # nosec
+                pass
+
 
 class SecretsController(controllers.ACLMixin):
     """Handles Secret creation requests."""
