@@ -23,6 +23,7 @@ import os
 from oslo_config import cfg
 from oslo_log import log
 from oslo_middleware import cors
+from oslo_policy import opts as policy_opts
 from oslo_service import _options
 
 from barbican import i18n as u
@@ -89,7 +90,7 @@ db_opts = [
     cfg.IntOpt('sql_retry_interval', default=1,
                help=u._("Interval between retries of opening a SQL "
                         "connection.")),
-    cfg.BoolOpt('db_auto_create', default=True,
+    cfg.BoolOpt('db_auto_create', default=False,
                 help=u._("Create the Barbican database on service startup.")),
     cfg.IntOpt('max_limit_paging', default=100,
                help=u._("Maximum page size for the 'limit' paging URL "
@@ -322,6 +323,24 @@ def setup_remote_pydev_debug():
             raise
 
 
+def set_lib_defaults():
+    """Update default value for configuration options from other namespace.
+
+    Example, oslo lib config options. This is needed for
+    config generator tool to pick these default value changes.
+    https://docs.openstack.org/oslo.config/latest/cli/
+    generator.html#modifying-defaults-from-other-namespaces
+    """
+
+    set_middleware_defaults()
+
+    # TODO(gmann): Remove setting the default value of config policy_file
+    # once oslo_policy change the default value to 'policy.yaml'.
+    # https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+    DEFAULT_POLICY_FILE = 'policy.yaml'
+    policy_opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
+
+
 def set_middleware_defaults():
     """Update default configuration options for oslo.middleware."""
     cors.set_defaults(
@@ -352,6 +371,7 @@ def set_middleware_defaults():
                        'PATCH']
     )
 
+
 CONF = new_config()
 LOG = logging.getLogger(__name__)
 parse_args(CONF)
